# Scrape-A-Long

Library for scraping data from web sites with async flavour

## Install

```sh
pip install scrapealong
```

## References

* [Home](https://pypi.org/project/scrapealong/0.1.0/)
* [Source](https://github.com/manuelep/scrapealong2)
